==> ehome-rcm-0.12.3.tgz: package/es/form-view/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React, { PureComponent, Component } from 'react';
import PropTypes from 'prop-types'; // eslint-disable-next-line import/no-cycle

import fields from './fields';
import customFields from './customFields';
import { CUSTOM } from './variables/fieldTypes';

var FieldView =
/*#__PURE__*/
function (_ref) {
  _inherits(FieldView, _ref);

  function FieldView(props) {
    var _this;

    _classCallCheck(this, FieldView);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(FieldView).call(this, props));
    _this.state = {};
    return _this;
  }

  _createClass(FieldView, [{
    key: "render",
    value: function render() {
      // eslint-disable-next-line prefer-const
      var _this$props = this.props,
          formFields = _this$props.formFields,
          layoutType = _this$props.layoutType,
          nullDisplayType = _this$props.nullDisplayType;
      layoutType = Number(layoutType);
      nullDisplayType = Number(nullDisplayType);
      var prefixCls = 'eh-field-view';
      var commonPrefixCls = layoutType === 0 ? "".concat(prefixCls, "-hor") : "".concat(prefixCls, "-ver");
      var fieldNameLens = formFields.map(function (item) {
        return item.fieldName ? item.fieldName.length : 0;
      });
      var maxNameLength = Math.max.apply(Math, _toConsumableArray(fieldNameLens)); // 统一字段label的宽度

      var labelWidth = "".concat(maxNameLength * 34 / 100, "rem");
      return React.createElement("div", {
        className: "".concat(prefixCls, " ").concat(commonPrefixCls)
      }, formFields.map(function (field, index) {
        var fieldType = field.fieldType,
            fieldCustomType = field.fieldCustomType;
        var FieldComponent;

        if (fieldType !== CUSTOM) {
          FieldComponent = fields[fieldType];
        } else {
          FieldComponent = customFields[fieldCustomType];
        }

        if (FieldComponent) {
          return React.createElement(FieldComponent, {
            key: index,
            field: field,
            layoutType: layoutType,
            nullDisplayType: nullDisplayType,
            labelWidth: labelWidth,
            commonPrefixCls: commonPrefixCls
          });
        }

        return null;
      }));
    }
  }]);

  return FieldView;
}(PureComponent || Component);

FieldView.PropTypes = {
  formFields: PropTypes.array,
  // 表单值数据
  layoutType: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  // 字段的布局类型：0 - 左右结构（默认），1 - 上下结构
  nullDisplayType: PropTypes.oneOfType([PropTypes.number, PropTypes.string]) // 字段值为空时，显示的类型：0 - 显示'无'（默认），1 - 字段不显示

};
FieldView.defaultProps = {
  formFields: [],
  layoutType: 0,
  nullDisplayType: 0
};
export default FieldView;

==> ehome-rcm-0.15.2.tgz: package/es/form-view/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(n); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { return function () { var Super = _getPrototypeOf(Derived), result; if (_isNativeReflectConstruct()) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React, { PureComponent, Component } from 'react';
import PropTypes from 'prop-types'; // eslint-disable-next-line import/no-cycle

import fields from './fields';
import customFields from './customFields';
import { CUSTOM } from './variables/fieldTypes';

var FieldView = /*#__PURE__*/function (_ref) {
  _inherits(FieldView, _ref);

  var _super = _createSuper(FieldView);

  function FieldView(props) {
    var _this;

    _classCallCheck(this, FieldView);

    _this = _super.call(this, props);
    _this.state = {};
    return _this;
  }

  _createClass(FieldView, [{
    key: "render",
    value: function render() {
      // eslint-disable-next-line prefer-const
      var _this$props = this.props,
          formFields = _this$props.formFields,
          layoutType = _this$props.layoutType,
          nullDisplayType = _this$props.nullDisplayType;
      layoutType = Number(layoutType);
      nullDisplayType = Number(nullDisplayType);
      var prefixCls = 'eh-field-view';
      var commonPrefixCls = layoutType === 0 ? "".concat(prefixCls, "-hor") : "".concat(prefixCls, "-ver");
      var fieldNameLens = formFields.map(function (item) {
        return item.fieldName ? item.fieldName.length : 0;
      });
      var maxNameLength = Math.max.apply(Math, _toConsumableArray(fieldNameLens)); // 统一字段label的宽度

      var labelWidth = "".concat(maxNameLength * 34 / 100, "rem");
      return /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, " ").concat(commonPrefixCls)
      }, formFields.map(function (field, index) {
        var fieldType = field.fieldType,
            fieldCustomType = field.fieldCustomType;
        var FieldComponent;

        if (fieldType !== CUSTOM) {
          FieldComponent = fields[fieldType];
        } else {
          FieldComponent = customFields[fieldCustomType];
        }

        if (FieldComponent) {
          return /*#__PURE__*/React.createElement(FieldComponent, {
            key: index,
            field: field,
            layoutType: layoutType,
            nullDisplayType: nullDisplayType,
            labelWidth: labelWidth,
            commonPrefixCls: commonPrefixCls
          });
        }

        return null;
      }));
    }
  }]);

  return FieldView;
}(PureComponent || Component);

FieldView.PropTypes = {
  formFields: PropTypes.array,
  // 表单值数据
  layoutType: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  // 字段的布局类型：0 - 左右结构（默认），1 - 上下结构
  nullDisplayType: PropTypes.oneOfType([PropTypes.number, PropTypes.string]) // 字段值为空时，显示的类型：0 - 显示'无'（默认），1 - 字段不显示

};
FieldView.defaultProps = {
  formFields: [],
  layoutType: 0,
  nullDisplayType: 0
};
export default FieldView;
